/// <reference types="node" />
import { Readable } from 'stream';
import createError = require('http-errors');
export interface Headers {
    [key: string]: string | string[];
}
export interface Options {
    limit?: number;
    encoding?: string;
    decoders?: Decoders;
    jsonTypes?: string[];
    formTypes?: string[];
    textTypes?: string[];
    jsonParse?: (str: string) => any;
    formParse?: (str: string) => any;
}
export interface Decoders {
    [key: string]: (stream: Readable) => Readable;
}
/**
 * Supported encodings.
 */
export declare const decoders: Decoders;
/**
 * Default support content types.
 */
export declare const jsonTypes: string[];
export declare const formTypes: string[];
export declare const textTypes: string[];
/**
 * Parse any incoming stream.
 */
export declare function parse(stream: Readable, headers: Headers, options?: Options): Promise<any>;
/**
 * Parse the stream as JSON.
 */
export declare function json(stream: Readable, headers: Headers, options?: Options): Promise<any>;
/**
 * Parse the stream as a form.
 */
export declare function form(stream: Readable, headers: Headers, options?: Options): Promise<any>;
/**
 * Parse the stream as text.
 */
export declare function text(stream: Readable, headers: Headers, options?: Options): Promise<string>;
/**
 * Inflate the readable stream.
 */
export declare function inflate(stream: Readable, headers: Headers, encoding?: Decoders): [createError.HttpError | undefined, Readable, number | undefined];
/**
 * Return the `content-type` string.
 */
export declare function getType(headers: Headers): string | undefined;
