"use strict";
var servie_1 = require("servie");
var zlib_1 = require("zlib");
var _1 = require("./");
describe('get-body', function () {
    describe('text', function () {
        it('should parse body as text', function () {
            var req = new servie_1.Request({ url: '', body: 'hello world' });
            return _1.parse(req.stream(), req.headers.object())
                .then(function (body) { return expect(body).toEqual('hello world'); });
        });
        it('should support gzip', function () {
            var req = new servie_1.Request({ url: '', body: 'hello world', headers: { 'Content-Encoding': 'gzip' } });
            return _1.parse(req.stream().pipe(zlib_1.createGzip()), req.headers.object())
                .then(function (body) { return expect(body).toEqual('hello world'); });
        });
        it('should support deflate', function () {
            var req = new servie_1.Request({ url: '', body: 'hello world', headers: { 'Content-Encoding': 'deflate' } });
            return _1.parse(req.stream().pipe(zlib_1.createDeflate()), req.headers.object())
                .then(function (body) { return expect(body).toEqual('hello world'); });
        });
    });
    describe('json', function () {
        it('should parse body as json', function () {
            var req = new servie_1.Request({ url: '', body: { hello: 'world' } });
            return _1.parse(req.stream(), req.headers.object())
                .then(function (body) { return expect(body).toEqual({ hello: 'world' }); });
        });
        it('should accept empty strings', function () {
            var req = new servie_1.Request({ url: '', body: '', headers: { 'Content-Type': 'application/json' } });
            return _1.parse(req.stream(), req.headers.object())
                .then(function (body) { return expect(body).toEqual({}); });
        });
        it('should not accept primitive json', function () {
            var req = new servie_1.Request({ url: '', body: JSON.stringify('test'), headers: { 'Content-Type': 'application/json; charset=utf-8' } });
            return _1.parse(req.stream(), req.headers.object())
                .catch(function (err) { return expect(err.message).toEqual('Invalid JSON, only supports object and array'); });
        });
    });
    describe('form', function () {
        it('should parse body as a form', function () {
            var req = new servie_1.Request({ url: '', body: 'hello=world', headers: { 'Content-Type': 'application/x-www-form-urlencoded' } });
            return _1.parse(req.stream(), req.headers.object())
                .then(function (body) { return expect(body).toEqual({ hello: 'world' }); });
        });
    });
    describe('errors', function () {
        it('should error on unknown content types', function () {
            var req = new servie_1.Request({ url: '', body: '', headers: { 'Content-Type': 'foo/bar' } });
            return _1.parse(req.stream(), req.headers.object())
                .catch(function (err) { return expect(err.message).toEqual('Unsupported content-type: foo/bar'); });
        });
        it('should error on no content type', function () {
            var req = new servie_1.Request({ url: '' });
            return _1.parse(req.stream(), req.headers.object())
                .catch(function (err) { return expect(err.message).toEqual('Missing content-type'); });
        });
        it('should error on unknown content encoding', function () {
            var req = new servie_1.Request({ url: '', body: '', headers: { 'Content-Type': 'application/json', 'Content-Encoding': 'foobar' } });
            return _1.parse(req.stream(), req.headers.object())
                .catch(function (err) { return expect(err.message).toEqual('Unsupport content-encoding: foobar'); });
        });
    });
});
//# sourceMappingURL=index.spec.js.map